@@ -30,7 +30,10 @@ def init():
         sys.exit(1)
 
     shutil.copytree(source_dir, dest_dir)
-    click.secho(f"Vite source directory and starter content installed in '{dest_dir}'.", fg="green")
+    click.secho(
+        f"Vite source directory and starter content installed in '{dest_dir}'.",
+        fg="green",
+    )
 
 
 @command()
